//@line 36 "/builds/slave/places-mobile-browser-linux-nightly/build/places/mobile/locales/en-US/mobile-l10n.js"

//@line 38 "/builds/slave/places-mobile-browser-linux-nightly/build/places/mobile/locales/en-US/mobile-l10n.js"

pref("general.useragent.locale", "en-US");
